# macchiato

[![macchiatos CI](https://github.com/fernandezfran/macchiato/actions/workflows/CI.yml/badge.svg)](https://github.com/fernandezfran/macchiato/actions/workflows/CI.yml)
[![documentation status](https://readthedocs.org/projects/macchiato/badge/?version=latest)](https://macchiato.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://img.shields.io/pypi/v/macchiato)](https://pypi.org/project/macchiato/)
[![python version](https://img.shields.io/badge/python-3.8%2B-4584b6)](https://www.python.org/)
[![mit license](https://img.shields.io/badge/License-MIT-ffde57)](https://github.com/fernandezfran/macchiato/blob/main/LICENSE)
[![PRB](https://img.shields.io/badge/PhysRevB-108.144201-b31033)](https://doi.org/10.1103/PhysRevB.108.144201)

Data-driven nearest neighbor models for predicting experimental results on 
silicon lithium-ion battery anodes.

## Requirements

You need Python 3.8+ to run macchiato.


## Installation

You can install the most recent stable release of macchiato with 
[pip](https://pip.pypa.io/en/latest/)

```
python -m pip install -U pip
python -m pip install -U macchiato
```


## Usage

The Jupyter Notebook pipeline in the 
[paper folder](https://github.com/fernandezfran/macchiato/tree/main/paper) 
is presented to reproduce the results of the published article.


## Citation

> Fernandez, F., Otero, M., Oviedo, M. B., Barraco, D. E., Paz, S. A., & Leiva, 
> E. P. M. (2023). NMR, x-ray, and Mössbauer results for amorphous Li-Si alloys 
> using density functional tight-binding method. Physical Review B, 108(14), 144201. 

BibTeX entry:

```bibtex
@article{fernandez2023nmr,
  title={NMR, x-ray, and M{\"o}ssbauer results for amorphous Li-Si alloys using density functional tight-binding method},
  author={Fernandez, F and Otero, M and Oviedo, MB and Barraco, DE and Paz, SA and Leiva, EPM},
  journal={Physical Review B},
  volume={108},
  number={14},
  pages={144201},
  year={2023},
  publisher={APS}
}
```


## Contact

You can contact me if you have any questions at <ffernandev@gmail.com>
